Corrected project name in header comments
[pulseview.git] / main.cpp
index bb95f9ba4ef8e0e0ad9467ba6e8b0829b847e901..d15cff89ee61ed852be33065e764be35e5253366 100644 (file)
--- a/main.cpp
+++ b/main.cpp
@@ -1,5 +1,5 @@
 /*
* This file is part of the sigrok project.
  *
  * Copyright (C) 2012 Joel Holdsworth <joel@airwebreathe.org.uk>
  *
@@ -34,7 +34,7 @@ int main(int argc, char *argv[])
 
        /* Set some application metadata. */
        QApplication::setApplicationVersion(APP_VERSION);
-       QApplication::setApplicationName("sigrok-qt");
+       QApplication::setApplicationName("PulseView");
        QApplication::setOrganizationDomain("http://www.sigrok.org");
 
        /* Initialise libsigrok */
@@ -52,6 +52,16 @@ int main(int argc, char *argv[])
        /* Load the protocol decoders */
        srd_decoder_load_all();
 
+       /* Initialize all libsigrok drivers. */
+       sr_dev_driver **const drivers = sr_driver_list();
+       for (sr_dev_driver **driver = drivers; *driver; driver++) {
+               if (sr_driver_init(*driver) != SR_OK) {
+                       qDebug("Failed to initialize driver %s",
+                               (*driver)->name);
+                       return 1;
+               }
+       }
+
        /* Initialise the main window */
        MainWindow w;
        w.show();
@@ -1,5 +1,5 @@
 /*
- * This file is part of the sigrok project.
+ * This file is part of the PulseView project.
  *
  * Copyright (C) 2012 Joel Holdsworth <joel@airwebreathe.org.uk>